@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/get.c,v 1.20 2003/03/25 19:26:10 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/get.c,v 1.22 2003/10/02 19:16:16 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -24,6 +24,8 @@
 #include <ctype.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <langinfo.h>
+#include <locale.h>
 #include <sys/types.h>
 #include <sys/file.h>
 #include <sys/param.h>
@@ -112,6 +114,20 @@ get_key_val(int *val, char *str)
 }
 
 
+/* Return the radix character. For most locales, this is a period. */
+
+char
+get_radix_char()
+{
+    char *radix_char;
+
+    setlocale(LC_NUMERIC, "");
+    radix_char = nl_langinfo(RADIXCHAR);
+
+    return(radix_char[0]);
+}
+
+
 void
 get_options(int argc, char *argv[])      /* Extract command line options. */
 {
