@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/graphics.c,v 1.17 2003/02/20 15:50:37 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/graphics.c,v 1.20 2003/06/24 14:53:31 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -32,10 +32,10 @@ void
 handle_menu_selection(struct button *n, int item)
 {
     if (item != -1) {
-        if (IS_KEY(v->pending, KEY_LPAR.value)) {   /* Inside parentheses? */
-            v->current->value = n->value;
+        if (IS_KEY(v->pending, KEY_LPAR.value[0])) {  /* Inside parentheses? */
+            v->current->value[0] = n->value[0];
             do_paren();
-            v->current->value = item;
+            v->current->value[0] = item;
             do_paren();
         } else {
             save_pending_values(n);
@@ -61,7 +61,7 @@ make_registers()            /* Calculate memory register frame values. */
     int n;
 
     for (n = 0; n < MAXREGS; n++) {
-        mval = make_number(v->MPmvals[n], FALSE);
+        mval = make_number(v->MPmvals[n], v->base, FALSE, TRUE);
 	SPRINTF(fmt, "<span weight=\"bold\">%s%s%%%1ds", 
                 _("R"), "%1d:</span>   %s", MAX_DIGITS - strlen(mval));
         SPRINTF(line, fmt, n, mval, " ");
@@ -91,7 +91,7 @@ process_stack(int startop,      /* Initial position in the operand stack. */
         } else {
             v->cur_ch = v->opstack[startop + i];
             if (v->pending) {
-                v->current->value = v->cur_ch;
+                v->current->value[0] = v->cur_ch;
                 do_pending();
             } else {
                 struct button *next = button_for_fc(v->cur_ch);
