@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.98 2003/08/18 16:21:58 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.102 2003/09/24 18:17:06 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -209,12 +209,12 @@ static GtkItemFactoryEntry lshift_menu[] = {
     { N_("/7 places"),  NULL, menu_proc, '7', NULL },
     { N_("/8 places"),  NULL, menu_proc, '8', NULL },
     { N_("/9 places"),  NULL, menu_proc, '9', NULL },
-    { N_("/10 places"), NULL, menu_proc, 'a', NULL },
-    { N_("/11 places"), NULL, menu_proc, 'b', NULL },
-    { N_("/12 places"), NULL, menu_proc, 'c', NULL },
-    { N_("/13 places"), NULL, menu_proc, 'd', NULL },
-    { N_("/14 places"), NULL, menu_proc, 'e', NULL },
-    { N_("/15 places"), NULL, menu_proc, 'f', NULL },
+    { N_("/10 places"), NULL, menu_proc, 'A', NULL },
+    { N_("/11 places"), NULL, menu_proc, 'B', NULL },
+    { N_("/12 places"), NULL, menu_proc, 'C', NULL },
+    { N_("/13 places"), NULL, menu_proc, 'D', NULL },
+    { N_("/14 places"), NULL, menu_proc, 'E', NULL },
+    { N_("/15 places"), NULL, menu_proc, 'F', NULL },
 };
 
 static GtkItemFactoryEntry rshift_menu[] = {
@@ -227,12 +227,12 @@ static GtkItemFactoryEntry rshift_menu[] = {
     { N_("/7 places"),  NULL, menu_proc, '7', NULL },
     { N_("/8 places"),  NULL, menu_proc, '8', NULL },
     { N_("/9 places"),  NULL, menu_proc, '9', NULL },
-    { N_("/10 places"), NULL, menu_proc, 'a', NULL },
-    { N_("/11 places"), NULL, menu_proc, 'b', NULL },
-    { N_("/12 places"), NULL, menu_proc, 'c', NULL },
-    { N_("/13 places"), NULL, menu_proc, 'd', NULL },
-    { N_("/14 places"), NULL, menu_proc, 'e', NULL },
-    { N_("/15 places"), NULL, menu_proc, 'f', NULL },
+    { N_("/10 places"), NULL, menu_proc, 'A', NULL },
+    { N_("/11 places"), NULL, menu_proc, 'B', NULL },
+    { N_("/12 places"), NULL, menu_proc, 'C', NULL },
+    { N_("/13 places"), NULL, menu_proc, 'D', NULL },
+    { N_("/14 places"), NULL, menu_proc, 'E', NULL },
+    { N_("/15 places"), NULL, menu_proc, 'F', NULL },
 };
 
 
@@ -909,6 +909,7 @@ static GtkWidget *
 create_mode_panel(GtkWidget *main_vbox)
 {
     int i;
+    AtkObject *access_object;
     GtkWidget *base_hbox, *disp_hbox, *trig_hbox;
     GtkWidget *row1_hbox, *row2_hbox, *frame, *vbox;
     GSList *base_gr = NULL;
@@ -939,6 +940,8 @@ create_mode_panel(GtkWidget *main_vbox)
         gtk_box_pack_start(GTK_BOX(trig_hbox), X->trig[i], FALSE, FALSE, 0);
         gtk_radio_button_set_group(GTK_RADIO_BUTTON(X->trig[i]), trig_gr);
         trig_gr = gtk_radio_button_get_group(GTK_RADIO_BUTTON(X->trig[i]));
+        access_object = gtk_widget_get_accessible(X->trig[i]);
+        atk_object_set_name(access_object, _(ttype_desc[i]));
         g_signal_connect(G_OBJECT(X->trig[i]), "toggled",
                          G_CALLBACK(trig_cb), NULL);
     }
@@ -958,6 +961,8 @@ create_mode_panel(GtkWidget *main_vbox)
         gtk_box_pack_start(GTK_BOX(base_hbox), X->base[i], FALSE, FALSE, 0);
         gtk_radio_button_set_group(GTK_RADIO_BUTTON(X->base[i]), base_gr);
         base_gr = gtk_radio_button_get_group(GTK_RADIO_BUTTON(X->base[i]));
+        access_object = gtk_widget_get_accessible(X->base[i]);
+        atk_object_set_name(access_object, _(base_desc[i]));
         g_signal_connect(G_OBJECT(X->base[i]), "toggled",
                          G_CALLBACK(base_cb), NULL);
     }
@@ -967,20 +972,20 @@ create_mode_panel(GtkWidget *main_vbox)
 /* Make Hyp and Inv trigonometric check boxes. */
 
     X->inv = gtk_check_button_new_with_mnemonic(_("_Inv"));
-    gtk_tooltips_set_tip(X->tips, X->inv, 
-                         _("Set inverse option for trigonometric functions"), "");
+    gtk_tooltips_set_tip(X->tips, X->inv, _(inv_desc), "");
     gtk_widget_show(X->inv);
     gtk_box_pack_start(GTK_BOX(row2_hbox), X->inv, FALSE, FALSE, 0);
-    g_signal_connect(G_OBJECT(X->inv), "toggled",
-                      G_CALLBACK(inv_cb), NULL);
+    access_object = gtk_widget_get_accessible(X->inv);
+    atk_object_set_name(access_object, _(inv_desc));
+    g_signal_connect(G_OBJECT(X->inv), "toggled", G_CALLBACK(inv_cb), NULL);
 
     X->hyp = gtk_check_button_new_with_mnemonic(_("H_yp"));
-    gtk_tooltips_set_tip(X->tips, X->hyp, 
-                         _("Set hyperbolic option for trigonometric functions"), "");
+    gtk_tooltips_set_tip(X->tips, X->hyp, _(hyp_desc), "");
     gtk_widget_show(X->hyp);
     gtk_box_pack_start(GTK_BOX(row2_hbox), X->hyp, FALSE, FALSE, 0);
-    g_signal_connect(G_OBJECT(X->hyp), "toggled",
-                      G_CALLBACK(hyp_cb), NULL);
+    access_object = gtk_widget_get_accessible(X->hyp);
+    atk_object_set_name(access_object, _(hyp_desc));
+    g_signal_connect(G_OBJECT(X->hyp), "toggled", G_CALLBACK(hyp_cb), NULL);
 
 /* Make display type radio button widgets. */
 
@@ -995,6 +1000,8 @@ create_mode_panel(GtkWidget *main_vbox)
         gtk_box_pack_start(GTK_BOX(disp_hbox), X->disp[i], FALSE, FALSE, 0);
         gtk_radio_button_set_group(GTK_RADIO_BUTTON(X->disp[i]), disp_gr);
         disp_gr = gtk_radio_button_get_group(GTK_RADIO_BUTTON(X->disp[i]));
+        access_object = gtk_widget_get_accessible(X->disp[i]);
+        atk_object_set_name(access_object, _(dtype_desc[i]));
         g_signal_connect(G_OBJECT(X->disp[i]), "toggled",
                          G_CALLBACK(disp_cb), NULL);
     }
@@ -1484,8 +1491,10 @@ make_but_frame(GtkWidget *vbox, GtkWidget **Gtk_buttons,
                             G_CALLBACK(button_proc), (gpointer) (j*cols + i));
             SPRINTF(name, "%s_button%1d", tag, n);
             gtk_widget_set_name(Gtk_buttons[n], name);
-            gtk_tooltips_set_tip(X->tips, Gtk_buttons[n],
-                                 _(buttons[n].hstr), "");
+            if (buttons[n].hstr != NULL) {
+                gtk_tooltips_set_tip(X->tips, Gtk_buttons[n],
+                                     _(buttons[n].hstr), "");
+            }
             g_object_set_data(G_OBJECT(Gtk_buttons[n]),
                               "button", &buttons[n]);
             gtk_widget_ref(Gtk_buttons[n]);
@@ -1617,6 +1626,7 @@ menu_button_key_press_cb(GtkWidget *widget,
         loc.y += widget->allocation.y;
         gtk_menu_popup(GTK_MENU(menu), NULL, NULL, menu_pos_func,
                        (gpointer) &loc, event->keyval, event->time);
+        return(TRUE);
     }
 
     return(FALSE);
